@@ -23,7 +23,6 @@
 #include <string.h>
 #include <gst/gst.h>
 #include <gst/app/gstappsink.h>
-#include <gst/app/gstappbuffer.h>
 
 #include "dmap-gst-input-stream.h"
 #include "dmap-gst-mp3-input-stream.h"
@@ -175,7 +174,10 @@ dmap_gst_input_stream_new_buffer_cb (GstElement * element,
 	gsize i;
 	guint8 *ptr;
 	GTimeVal time;
-	GstBuffer *buffer;
+	GstSample *sample = NULL;
+	GstBuffer *buffer = NULL;
+	GstMemory *memory = NULL;
+	GstMapInfo info;
 
 	/* FIXME: Is this necessary? I am trying to protect against this
 	 * thread manipulating data after the pipeline has been destroyed.
@@ -191,17 +193,33 @@ dmap_gst_input_stream_new_buffer_cb (GstElement * element,
 	g_get_current_time (&time);
 	g_time_val_add (&time, QUEUE_PUSH_WAIT_SECONDS * 1000000);
 
-	buffer = gst_app_sink_pull_buffer (GST_APP_SINK (element));
+	sample = gst_app_sink_pull_sample (GST_APP_SINK (element));
+	if (NULL == sample) {
+		g_warning ("Error getting GStreamer sample");
+		goto _return;
+	}
 
-	if (buffer == NULL) {
+	buffer = gst_sample_get_buffer (sample);
+	if (NULL == buffer) {
 		g_warning ("Error getting GStreamer buffer");
 		goto _return;
 	}
 
+	memory = gst_buffer_get_memory (buffer, 0);
+	if (NULL == memory) {
+		g_warning ("Error getting GStreamer memory");
+		goto _return;
+	}
+
+	if (gst_memory_map (memory, &info, GST_MAP_READ) == FALSE) {
+		g_warning ("Error mapping GStreamer memory");
+		goto _return;
+	}
+
 	/* FIXME: this actually allows buffer to grow larger than max. */
 	if (g_queue_get_length (stream->priv->buffer) +
-	    GST_BUFFER_SIZE (buffer) > DECODED_BUFFER_SIZE) {
-		stream->priv->write_request = GST_BUFFER_SIZE (buffer);
+	    info.size > DECODED_BUFFER_SIZE) {
+		stream->priv->write_request = info.size;
 		if (!g_cond_timed_wait (stream->priv->buffer_write_ready,
 					stream->priv->buffer_mutex, &time)) {
 			g_warning
@@ -217,17 +235,15 @@ dmap_gst_input_stream_new_buffer_cb (GstElement * element,
 	}
 
 	if (g_queue_get_length (stream->priv->buffer) +
-	    GST_BUFFER_SIZE (buffer) <= DECODED_BUFFER_SIZE) {
-		ptr = GST_BUFFER_DATA (buffer);
+	    info.size <= DECODED_BUFFER_SIZE) {
+		ptr = info.data;
 
-		for (i = 0; i < GST_BUFFER_SIZE (buffer); i++) {
+		for (i = 0; i < info.size; i++) {
 			g_queue_push_tail (stream->priv->buffer,
 					   GINT_TO_POINTER ((gint) * ptr++));
 		}
 	}
 
-	gst_buffer_unref (buffer);
-
 	if (g_queue_get_length (stream->priv->buffer)
 	    >= stream->priv->read_request) {
 		stream->priv->read_request = 0;
@@ -235,6 +251,14 @@ dmap_gst_input_stream_new_buffer_cb (GstElement * element,
 	}
 
       _return:
+	if (NULL != memory) {
+		gst_memory_unmap (memory, &info);
+	}
+
+	if (NULL != sample) {
+		gst_sample_unref (sample);
+	}
+
 	g_mutex_unlock (stream->priv->buffer_mutex);
 }
 
@@ -252,6 +276,9 @@ dmap_gst_input_stream_new (const gchar * transcode_mimetype,
 	} else if (!strcmp (transcode_mimetype, "audio/wav")) {
 		stream = G_INPUT_STREAM (dmap_gst_wav_input_stream_new
 					 (src_stream));
+	} else if (!strcmp (transcode_mimetype, "video/quicktime")) {
+		stream = G_INPUT_STREAM (dmap_gst_qt_input_stream_new
+					 (src_stream));
 	} else {
 		g_warning ("Transcode format %s not supported",
 			   transcode_mimetype);
@@ -300,14 +327,12 @@ dmap_gst_input_stream_read (GInputStream * stream,
 		/* Depending on timing, more data may have been written
 		 * since check: do not pull more than count:
 		 */
-		count = min (count,
-			     g_queue_get_length (gst_stream->priv->buffer));
+		count = min (count, g_queue_get_length (gst_stream->priv->buffer));
 	}
 
 	for (i = 0; i < count; i++) {
 		((guint8 *) buffer)[i] =
-			GPOINTER_TO_INT (g_queue_pop_head
-					 (gst_stream->priv->buffer));
+			GPOINTER_TO_INT (g_queue_pop_head (gst_stream->priv->buffer));
 	}
 
 	if (gst_stream->priv->write_request > count)
