@@ -34,7 +34,7 @@ struct DMAPGstMP3InputStreamPrivate
 	GstElement *src;
 	GstElement *decode;
 	GstElement *convert;
-	GstElement *encode;
+	GstElement *audio_encode;
 	GstElement *sink;
 };
 
@@ -59,13 +59,6 @@ pad_added_cb (GstElement * element,
 			   (stream->priv->convert, "sink")));
 
 		gst_pad_link (pad, conv_pad);
-
-		if (gst_element_link_many (stream->priv->convert,
-					   stream->priv->encode,
-					   stream->priv->sink,
-					   NULL) == FALSE) {
-			g_warning ("Error linking convert and sink elements");
-		}
 	} else {
 		g_warning ("Could not link GStreamer pipeline.");
 	}
@@ -87,16 +80,14 @@ dmap_gst_mp3_input_stream_new (GInputStream * src_stream)
 	stream->priv->src = gst_element_factory_make ("giostreamsrc", "src");
 	g_assert (GST_IS_ELEMENT (stream->priv->src));
 
-	stream->priv->decode =
-		gst_element_factory_make ("decodebin2", "decode");
+	stream->priv->decode = gst_element_factory_make ("decodebin", "decode");
 	g_assert (GST_IS_ELEMENT (stream->priv->decode));
 
-	stream->priv->convert =
-		gst_element_factory_make ("audioconvert", "convert");
+	stream->priv->convert = gst_element_factory_make ("audioconvert", "convert");
 	g_assert (GST_IS_ELEMENT (stream->priv->convert));
 
-	stream->priv->encode = gst_element_factory_make ("lame", "encode");
-	g_assert (GST_IS_ELEMENT (stream->priv->encode));
+	stream->priv->audio_encode = gst_element_factory_make ("lamemp3enc", "audioencode");
+	g_assert (GST_IS_ELEMENT (stream->priv->audio_encode));
 
 	stream->priv->sink = gst_element_factory_make ("appsink", "sink");
 	g_assert (GST_IS_ELEMENT (stream->priv->sink));
@@ -105,31 +96,40 @@ dmap_gst_mp3_input_stream_new (GInputStream * src_stream)
 			  stream->priv->src,
 			  stream->priv->decode,
 			  stream->priv->convert,
-			  stream->priv->encode, stream->priv->sink, NULL);
+			  stream->priv->audio_encode,
+	                  stream->priv->sink,
+	                  NULL);
 
-	if (gst_element_link (stream->priv->src, stream->priv->decode) ==
-	    FALSE) {
+	if (gst_element_link (stream->priv->src,
+	                      stream->priv->decode) == FALSE) {
 		g_warning ("Error linking source and decode elements");
 	}
 
+	if (gst_element_link_many (stream->priv->convert,
+	                           stream->priv->audio_encode,
+	                           stream->priv->sink,
+	                           NULL) == FALSE) {
+		g_warning ("Error linking convert through sink elements");
+	}
+
 	g_assert (G_IS_INPUT_STREAM (src_stream));
 	g_object_set (G_OBJECT (stream->priv->src), "stream", src_stream,
 		      NULL);
 
 	/* quality=9 is important for fast, realtime transcoding: */
-	g_object_set (G_OBJECT (stream->priv->encode), "quality", 9, NULL);
-	g_object_set (G_OBJECT (stream->priv->encode), "bitrate", 128, NULL);
-	g_object_set (G_OBJECT (stream->priv->encode), "vbr", 0, NULL);
+	// FIXME: Causes crash; why?
+	// g_object_set (G_OBJECT (stream->priv->audio_encode), "quality", 9, NULL);
+	g_object_set (G_OBJECT (stream->priv->audio_encode), "bitrate", 128, NULL);
+	g_object_set (G_OBJECT (stream->priv->audio_encode), "vbr", 0, NULL);
 	g_signal_connect (stream->priv->decode, "pad-added",
 			  G_CALLBACK (pad_added_cb), stream);
 
 	g_object_set (G_OBJECT (stream->priv->sink), "emit-signals", TRUE,
 		      "sync", FALSE, NULL);
-	gst_app_sink_set_max_buffers (GST_APP_SINK (stream->priv->sink),
-				      GST_APP_MAX_BUFFERS);
+	gst_app_sink_set_max_buffers (GST_APP_SINK (stream->priv->sink), GST_APP_MAX_BUFFERS);
 	gst_app_sink_set_drop (GST_APP_SINK (stream->priv->sink), FALSE);
 
-	g_signal_connect (stream->priv->sink, "new-buffer",
+	g_signal_connect (stream->priv->sink, "new-sample",
 			  G_CALLBACK (dmap_gst_input_stream_new_buffer_cb),
 			  stream);
 
