@@ -35,7 +35,7 @@ struct DMAPGstWAVInputStreamPrivate
 	GstElement *decode;
 	GstElement *convert;
 	GstCaps *filter;
-	GstElement *encode;
+	GstElement *audio_encode;
 	GstElement *sink;
 };
 
@@ -60,18 +60,6 @@ pad_added_cb (GstElement * element,
 			   (stream->priv->convert, "sink")));
 
 		gst_pad_link (pad, conv_pad);
-
-		if (gst_element_link_filtered (stream->priv->convert,
-					       stream->priv->encode,
-					       stream->priv->filter) ==
-		    FALSE) {
-			g_warning
-				("Error linking convert and encode elements");
-		}
-		if (gst_element_link (stream->priv->encode,
-				      stream->priv->sink) == FALSE) {
-			g_warning ("Error linking encode and sink elements");
-		}
 	} else {
 		g_warning ("Could not link GStreamer pipeline.");
 	}
@@ -94,7 +82,7 @@ dmap_gst_wav_input_stream_new (GInputStream * src_stream)
 	g_assert (GST_IS_ELEMENT (stream->priv->src));
 
 	stream->priv->decode =
-		gst_element_factory_make ("decodebin2", "decode");
+		gst_element_factory_make ("decodebin", "decode");
 	g_assert (GST_IS_ELEMENT (stream->priv->decode));
 
 	stream->priv->convert =
@@ -107,8 +95,8 @@ dmap_gst_wav_input_stream_new (GInputStream * src_stream)
 						    "width", G_TYPE_INT, 16,
 						    "depth", G_TYPE_INT, 16,
 						    NULL);
-	stream->priv->encode = gst_element_factory_make ("wavenc", "encode");
-	g_assert (GST_IS_ELEMENT (stream->priv->encode));
+	stream->priv->audio_encode = gst_element_factory_make ("wavenc", "audioencode");
+	g_assert (GST_IS_ELEMENT (stream->priv->audio_encode));
 
 	stream->priv->sink = gst_element_factory_make ("appsink", "sink");
 	g_assert (GST_IS_ELEMENT (stream->priv->sink));
@@ -117,11 +105,24 @@ dmap_gst_wav_input_stream_new (GInputStream * src_stream)
 			  stream->priv->src,
 			  stream->priv->decode,
 			  stream->priv->convert,
-			  stream->priv->encode, stream->priv->sink, NULL);
+			  stream->priv->audio_encode,
+	                  stream->priv->sink,
+	                  NULL);
 
-	if (gst_element_link (stream->priv->src, stream->priv->decode) ==
-	    FALSE) {
-		g_warning ("Error linking source and decode elements");
+	if (gst_element_link (stream->priv->src, 
+	                      stream->priv->decode) == FALSE) {
+		g_warning ("Error linking source through decode elements");
+	}
+
+	if (gst_element_link_filtered (stream->priv->convert,
+	                               stream->priv->audio_encode,
+	                               stream->priv->filter) == FALSE) {
+		g_warning ("Error linking convert and audioencode elements");
+	}
+
+	if (gst_element_link (stream->priv->audio_encode,
+	                      stream->priv->sink) == FALSE) {
+		g_warning ("Error linking audioencode and sink elements");
 	}
 
 	g_object_set (G_OBJECT (stream->priv->src), "stream", src_stream,
